@@ -2,9 +2,9 @@
 #'
 #' Generates a term matrix for text classification use in \link{NNS.reg}.
 #'
-#' @param x Text A two column dataset should be used.  Concatenate text from original sources to comply with format.  Also note the possiblity of factors in \code{"DV"}, so \code{"as.numeric(as.character(...))"} is used to avoid issues.
-#' @param oos Out-of-sample text dataset to be classified.
-#' @param names Column names for \code{"IV"} and \code{"oos"}.  Defaults to FALSE.
+#' @param x mixed data.frame; character/numeric; A two column dataset should be used.  Concatenate text from original sources to comply with format.  Also note the possibility of factors in \code{"DV"}, so \code{"as.numeric(as.character(...))"} is used to avoid issues.
+#' @param oos mixed data.frame; character/numeric; Out-of-sample text dataset to be classified.
+#' @param names logical; Column names for \code{"IV"} and \code{"oos"}.  Defaults to FALSE.
 #' @return Returns the text as independent variables \code{"IV"} and the classification as the dependent variable \code{"DV"}.  Out-of-sample independent variables are returned with \code{"OOS"}.
 #' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
 #' \url{https://www.amazon.com/dp/1490523995/ref=cm_sw_su_dp}
@@ -12,7 +12,7 @@
 #' x <- data.frame(cbind(c("sunny", "rainy"), c(1, -1)))
 #' NNS.term.matrix(x)
 #'
-#' ### Concatenate Text with space seperator, cbind with "DV"
+#' ### Concatenate Text with space separator, cbind with "DV"
 #' x <- data.frame(cbind(c("sunny", "rainy"), c("windy", "cloudy"), c(1, -1)))
 #' x <- data.frame(cbind(paste(x[ , 1], x[ , 2], sep = " "), as.numeric(as.character(x[ , 3]))))
 #' NNS.term.matrix(x)
@@ -32,6 +32,8 @@
 
 NNS.term.matrix <- function(x, oos = NULL, names = FALSE){
 
+  if(any(class(x)=="tbl")) x <- as.data.frame(x)
+
   p <- length(oos)
 
   x <- t(t(x))
@@ -67,9 +69,7 @@ NNS.term.matrix <- function(x, oos = NULL, names = FALSE){
   #Remove prepositions
   preps <- unique.vocab %in% c(prepositions)
 
-  if(sum(preps) > 0){
-      unique.vocab <- unique.vocab[!preps]
-  }
+  if(sum(preps) > 0) unique.vocab <- unique.vocab[!preps]
 
   if(!is.null(oos)){
       oos.preps <- oos %in% c(prepositions)
@@ -80,19 +80,16 @@ NNS.term.matrix <- function(x, oos = NULL, names = FALSE){
 
   NNS.TM <- (t(sapply(1 : length(x[ , 1]), function(i) stringr::str_count(x[i, 1], unique.vocab))))
 
-  if(names){
-      colnames(NNS.TM) <- c(unique.vocab)
-  }
+  if(names) colnames(NNS.TM) <- c(unique.vocab)
 
   if(!is.null(oos)){
       OOS.TM <- (t(sapply(1 : length(oos), function(i) stringr::str_count(oos[i], unique.vocab))))
-  if(names){
-      colnames(OOS.TM) <- c(unique.vocab)
-  }
 
-  return(list("IV" = NNS.TM,
-              "DV" = as.numeric(as.character(x[ , 2])),
-              "OOS" = OOS.TM))
+      if(names) colnames(OOS.TM) <- c(unique.vocab)
+
+      return(list("IV" = NNS.TM,
+                  "DV" = as.numeric(as.character(x[ , 2])),
+                  "OOS" = OOS.TM))
   } else {
       return(list("IV" = NNS.TM,
                 "DV" = as.numeric(as.character(x[ , 2]))))
